@@ -1,6 +1,6 @@
 package List::Objects::WithUtils;
 {
-  $List::Objects::WithUtils::VERSION = '1.006001';
+  $List::Objects::WithUtils::VERSION = '1.007000';
 }
 use Carp;
 use strictures 1;
@@ -53,7 +53,9 @@ sub import {
     if ($@) { carp $@; push @failed, $mod }
   }
 
-  confess "Failed to import ".join ', ', @failed if @failed;
+  if (@failed) {
+    confess 'Failed to import ' . join ', ', @failed
+  }
 
   1
 }
@@ -70,7 +72,7 @@ unless caller;
 
 =head1 NAME
 
-List::Objects::WithUtils - Object interfaces to lists with useful methods
+List::Objects::WithUtils - List objects with useful methods
 
 =head1 SYNOPSIS
 
@@ -91,8 +93,8 @@ List::Objects::WithUtils - Object interfaces to lists with useful methods
   # Some simple chained array operations, eventually returning a plain list
   # List returning methods return new list objects:
   array(qw/ aa Ab bb Bc bc /)
-    ->grep(sub { $_[0] =~ /^b/i })
-    ->map(sub { uc $_[0] })
+    ->grep(sub { /^b/i })
+    ->map(sub { uc })
     ->uniq
     ->all;   # ( 'BB', 'BC' )
 
@@ -159,8 +161,8 @@ List::Objects::WithUtils - Object interfaces to lists with useful methods
 
   # Chained method examples; methods that return multiple values
   # typically return array-type objects:
-  my @match_keys = $hash->keys->grep(sub { $_[0] =~ /foo/ })->all;
-  my @match_vals = $hash->values->grep(sub { $_[0] =~ /bar/ })->all;
+  my @match_keys = $hash->keys->grep(sub { m/foo/ })->all;
+  my @match_vals = $hash->values->grep(sub { m/bar/ })->all;
   
   my @sorted_pairs = hash( foo => 2, bar => 3, baz => 1)
     ->kv
