@@ -1,6 +1,6 @@
 package List::Objects::WithUtils::Role::Array;
 {
-  $List::Objects::WithUtils::Role::Array::VERSION = '1.006001';
+  $List::Objects::WithUtils::Role::Array::VERSION = '1.007000';
 }
 use strictures 1;
 
@@ -36,6 +36,12 @@ sub blessed_or_pkg {
       return ARRAY_TYPE
 }
 
+sub __flatten {
+  ref $_[0] && Scalar::Util::reftype $_[0] eq 'ARRAY' ?
+    map {; __flatten($_) } @{ $_[0] }
+    : $_[0]
+}
+
 
 use Role::Tiny;
 
@@ -210,6 +216,16 @@ sub part {
   )
 }
 
+sub bisect {
+  my ($self, $code) = @_;
+  my @parts = ( [], [] );
+  CORE::push @{ $parts[ $code->($_) ? 0 : 1 ] }, $_ for @$self;
+  my $cls = blessed_or_pkg($self);
+  $cls->new(
+    map {; $cls->new(@$_) } @parts
+  )
+}
+
 sub reduce {
   List::Util::reduce { $_[1]->($a, $b) } @{ $_[0] }
 }
@@ -268,6 +284,9 @@ sub uniq_by {
   )
 }
 
+sub flatten_all {
+  CORE::map {;  __flatten($_)  } @{ $_[0] }
+}
 
 
 1;
@@ -287,12 +306,16 @@ List::Objects::WithUtils::Role::Array - Array manipulation methods
 
   $array->push(qw/ d e f /);
 
-  my @upper = $array->map(sub { uc $_[0] })->all;
+  my @upper = $array->map(sub { uc })->all;
 
   if ( $array->has_any(sub { $_ eq 'a' }) ) {
     ...
   }
 
+  my $sum = array(1 .. 10)->reduce(sub { $_[0] + $_[1] });
+
+  # See below for full list of methods
+
   ## As a Role ->
   use Role::Tiny::With;
   with 'List::Objects::WithUtils::Role::Array';
@@ -319,41 +342,33 @@ Constructs a new ARRAY-type object.
 
 Creates a shallow clone of the current object.
 
-=head3 clear
-
-Clears the array entirely.
-
 =head3 count
 
 Returns the number of elements in the array.
 
-=head3 scalar
-
-See L</count>.
-
 =head3 is_empty
 
 Returns boolean true if the array is empty.
 
-=head3 all
+=head3 scalar
 
-Returns all elements in the array as a plain list.
+See L</count>.
 
-=head3 export
+=head2 Methods that manipulate the list
 
-Same as L</all>; included for consistency with hash-type objects.
+=head3 clear
 
-=head3 get
+Clears the array entirely.
 
-Returns the array element corresponding to a specified index.
+=head3 delete
 
-=head3 set
+Splices a given index out of the array.
 
-  $array->set( $index, $value );
+=head3 insert
 
-Takes an array element and a new value to set.
+  $array->insert( $position, $value );
 
-Returns the array object.
+Inserts a value at a given position.
 
 =head3 pop
 
@@ -365,6 +380,14 @@ Pushes elements to the end of the array.
 
 Returns the array object.
 
+=head3 set
+
+  $array->set( $index, $value );
+
+Takes an array element and a new value to set.
+
+Returns the array object.
+
 =head3 shift
 
 Shifts the first element off the beginning of the array and returns it.
@@ -375,23 +398,48 @@ Adds elements to the beginning of the array.
 
 Returns the array object.
 
-=head3 delete
+=head3 splice
 
-Splices a given index out of the array.
+  # 2-arg splice (remove elements):
+  my $spliced = $array->splice(0, 2)
+  # 3-arg splice (replace):
+  $array->splice(0, 1, 'abc');
 
-=head3 insert
+Performs a C<splice()> on the current list and returns a new array object
+consisting of the items returned from the splice.
 
-  $array->insert( $position, $value );
+The existing array is modified in-place.
 
-Inserts a value at a given position.
+=head2 Methods that retrieve items
 
-=head3 join
+=head3 all
 
-  my $str = $array->join(' ');
+Returns all elements in the array as a plain list.
 
-Joins the array's elements and returns the joined string.
+=head3 bisect
 
-Defaults to ',' if no delimiter is specified.
+  my ($true, $false) = array( 1 .. 10 )
+    ->bisect(sub { $_[0] >= 5 })
+    ->all;
+  my @bigger  = $true->all;   # ( 5 .. 10 )
+  my @smaller = $false->all;  # ( 1 .. 4 )
+
+Like L</part>, but creates an array-type object containing two
+partitions; the first contains all items for which the subroutine evaluates to
+true, the second contains the remaining items.
+
+=head3 export
+
+Same as L</all>; included for consistency with hash-type objects.
+
+=head3 flatten_all
+
+Returns a plain list consisting of all sub-arrays recursively
+flattened.
+
+=head3 get
+
+Returns the array element corresponding to a specified index.
 
 =head3 head
 
@@ -410,6 +458,14 @@ Similar to L</head>, but returns either the last element and a new array-type
 object containing the remaining list (in list context), or just the last
 element of the list (in scalar context).
 
+=head3 join
+
+  my $str = $array->join(' ');
+
+Joins the array's elements and returns the joined string.
+
+Defaults to ',' if no delimiter is specified.
+
 =head3 mesh
 
   my $meshed = array(qw/ a b c /)->mesh(
@@ -428,21 +484,6 @@ You can mix and match references and objects freely:
     [ qw/ foo bar baz / ],
   );
 
-=head3 natatime
-
-  my $iter = array( 1 .. 7 )->natatime(3);
-  $iter->();  ##  ( 1, 2, 3 )
-  $iter->();  ##  ( 4, 5, 6 )
-  $iter->();  ##  ( 7 )
-
-  array( 1 .. 7 )->natatime(3, sub { my @vals = @_; ... });
-
-Returns an iterator that, when called, produces a list containing the next
-'n' items.
-
-If given a coderef as a second argument, it will be called against each
-bundled group.
-
 =head3 part
 
   my $parts = array( 1 .. 8 )->part(sub { $i++ % 2 });
@@ -486,26 +527,7 @@ Returns a new array object containing the shuffled list.
 Returns a new array object consisting of the elements retrived 
 from the specified indexes.
 
-=head3 splice
-
-  ## 2-arg splice (remove elements):
-  my $spliced = $array->splice(0, 2)
-  ## 3-arg splice (replace):
-  $array->splice(0, 1, 'abc');
-
-Performs a C<splice()> on the current list and returns a new array object
-consisting of the items returned from the splice.
-
-The existing array is modified in-place.
-
-=head3 uniq
-
-  my $unique = $array->uniq;
-
-Returns a new array object containing only unique elements from the original
-array.
-
-=head2 Methods that take subs with params
+=head2 Methods that find items
 
 =head3 grep
 
@@ -513,31 +535,7 @@ array.
 
 Returns a new array object consisting of the list of elements for which the
 given subroutine evaluated to true. C<$_[0]> is the element being operated
-upon.
-
-=head3 map
-
-  my $lowercased = $array->map(sub { lc $_[0] });
-
-Evaluates a given subroutine for each element of the array, and returns a new
-array object. C<$_[0]> is the element being operated upon.
-
-=head3 reduce
-
-  my $sum = array(1,2,3)->reduce(sub { $_[0] + $_[1] });
-
-Reduces the array by calling the given subroutine for each element of the
-list. See L<List::Util/"reduce">.
-
-=head3 sort
-
-  my $sorted = $array->sort(sub { $_[0] cmp $_[1] });
-
-Returns a new array object consisting of the list sorted by the given
-subroutine. C<$_[0]> and C<$_[1]> are equivalent to C<$a> and C<$b> in a
-normal sort() call.
-
-=head2 Methods that take subs with topicalizer
+on; you can also use the topicalizer C<$_>.
 
 =head3 first
 
@@ -585,6 +583,50 @@ The opposite of L</items_after>.
 
 The opposite of L</items_after_incl>.
 
+=head2 Methods that iterate the list
+
+=head3 map
+
+  my $lowercased = $array->map(sub { lc });
+  # Same as:
+  my $lowercased = $array->map(sub { lc $_[0] });
+
+Evaluates a given subroutine for each element of the array, and returns a new
+array object. C<$_[0]> is the element being operated on; you can also use
+the topicalizer C<$_>.
+
+=head3 natatime
+
+  my $iter = array( 1 .. 7 )->natatime(3);
+  $iter->();  ##  ( 1, 2, 3 )
+  $iter->();  ##  ( 4, 5, 6 )
+  $iter->();  ##  ( 7 )
+
+  array( 1 .. 7 )->natatime(3, sub { my @vals = @_; ... });
+
+Returns an iterator that, when called, produces a list containing the next
+'n' items.
+
+If given a coderef as a second argument, it will be called against each
+bundled group.
+
+=head3 reduce
+
+  my $sum = array(1,2,3)->reduce(sub { $_[0] + $_[1] });
+
+Reduces the array by calling the given subroutine for each element of the
+list. See L<List::Util/"reduce">.
+
+=head2 Methods that sort the list
+
+=head3 sort
+
+  my $sorted = $array->sort(sub { $_[0] cmp $_[1] });
+
+Returns a new array object consisting of the list sorted by the given
+subroutine. C<$_[0]> and C<$_[1]> are equivalent to C<$a> and C<$b> in a
+normal sort() call.
+
 =head3 sort_by
 
   my $array = array(
@@ -602,6 +644,13 @@ See L<List::UtilsBy>.
 
 Like L</sort_by>, but using numerical comparison.
 
+=head3 uniq
+
+  my $unique = $array->uniq;
+
+Returns a new array object containing only unique elements from the original
+array.
+
 =head3 uniq_by
 
   my $array = array(
